/*
  Macro           ColorReporter
  Author          Carlo Hogeveen
  Website         eCarlo.nl/tse
  Compatibility   Tested with Windows GUI TSE v4.50 rc 11 - 2023 Sep 2
  Version         v1

  This extension continuously reports the color name of the character at the
  cursor.

  This is intended for testing, because it is not always possible to visually
  distinguish colors.


  INSTALLATION

  Just compile the macro and load it.
  Just purge the macro to stop it.
  There is no configuration.

*/

string  COLOR_NAMES   [46] = 'Black Blue Green Cyan Red Magenta Yellow White'
integer check_cursor_color = FALSE


proc report_cursor_color_step_3()
  string  cursor_color_name  [33] = ''
  integer cursor_background_color = 0
  string  cursor_character    [1] = ''
  integer cursor_color_attr       = 0
  string  cursor_color_char   [1] = ''
  integer cursor_foreground_color = 0
  integer cursor_video_x          = 0
  integer cursor_video_y          = 0
  integer msg_video_x             = 0
  integer msg_video_y             = 0

  cursor_video_x = Query(WindowX1) - 1 + CurrCol() - CurrXoffset()
  cursor_video_y = Query(WindowY1) - 1 + CurrRow()

  GetStrAttrXY(cursor_video_x, cursor_video_y,
               cursor_character, cursor_color_char, 1)

  cursor_color_attr       = Asc(cursor_color_char)
  cursor_background_color = cursor_color_attr  /  16
  cursor_foreground_color = cursor_color_attr mod 16


  cursor_color_name = iif(cursor_background_color > 7, 'Intense ', '')
                    + iif(cursor_foreground_color > 7, 'Bright ' , '')
                    + GetToken(COLOR_NAMES,
                               ' ',
                               (cursor_foreground_color mod 8) + 1)
                    + " on "
                    + GetToken(COLOR_NAMES,
                               ' ',
                               (cursor_background_color mod 8) + 1)

  msg_video_x = Query(WindowX1) - 1 + Query(WindowCols) - 44 + 1
  msg_video_y = Query(WindowY1) - 1 + Query(WindowRows)

  PutStrAttrXY(msg_video_x, msg_video_y,
               Format(Format('(', cursor_video_x, ',', cursor_video_y, ':';
                             cursor_color_name, ')'):-44),
               '', Color(Bright White ON Black))
end report_cursor_color_step_3


proc report_cursor_color_step_2()
  if check_cursor_color
    report_cursor_color_step_3()
    check_cursor_color = FALSE
  endif
end report_cursor_color_step_2


proc report_cursor_color_step_1()
  check_cursor_color = TRUE
end report_cursor_color_step_1


proc WhenLoaded()
  Hook(_AFTER_COMMAND_, report_cursor_color_step_1)
  Hook(_IDLE_         , report_cursor_color_step_2)
end WhenLoaded

